/*
 * Copyright (C) 2005  Network Applied Communication Laboratory Co., Ltd.
 *
 * This file is part of Rast.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 */

#ifndef RAST_PROPERTY_H
#define RAST_PROPERTY_H

/**
 * @file property.h property
 */

#include "rast/types.h"

/**
 * @defgroup property property
 * @{
 */

/** A structure that represents a property definition */
typedef struct {
    /** The name of the property */
    char *name;
    /** The type of the property */
    rast_type_e type;
    /**
     * The flags of the property
     *   - RAST_PROPERTY_FLAG_SEARCH
     *     - search by =,<,<=,>,>=
     *   - RAST_PROPERTY_FLAG_TEXT_SEARCH
     *     - search by :
     *   - RAST_PROPERTY_FLAG_FULL_TEXT_SEARCH
     *     - include to the index for full-text search
     *   - RAST_PROPERTY_FLAG_UNIQUE
     *     - property value should be unique
     */
    rast_uint_t flags;
} rast_property_t;

#define RAST_PROPERTY_FLAG_SEARCH           0x0001
#define RAST_PROPERTY_FLAG_TEXT_SEARCH      0x0002
#define RAST_PROPERTY_FLAG_FULL_TEXT_SEARCH 0x0004
#define RAST_PROPERTY_FLAG_UNIQUE           0x0008

/** @} */

#endif

/* vim: set filetype=c sw=4 expandtab : */
