/*
 * Copyright (C) 2005  Network Applied Communication Laboratory Co., Ltd.
 *
 * This file is part of Rast.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 */

#ifndef RAST_TYPES_H
#define RAST_TYPES_H

/**
 * @file types.h types
 */

/**
 * @defgroup types types
 * @{
 */

typedef apr_uint32_t rast_uint_t;
typedef rast_uint_t rast_size_t;
typedef rast_uint_t rast_doc_id_t;
typedef rast_uint_t rast_pos_t;

#define RAST_POS_MAX ((rast_pos_t) -1)

/** Enum for value types */
typedef enum {
    RAST_TYPE_STRING,  /**< string */
    RAST_TYPE_DATE,    /**< ISO 8601 format date/time */
    RAST_TYPE_UINT,    /**< unsigned integer */
} rast_type_e;

/** A structure that holds values */
typedef struct {
    rast_type_e type;
    union {
        char *string;
        rast_uint_t number;
    } value;
} rast_value_t;

/** Get the unsigned integer value */
#define rast_value_uint(x) ((x)->value.number)
/** Get the string value */
#define rast_value_string(x) ((x)->value.string)
/** Get the date/time value */
#define rast_value_date(x) ((x)->value.string)

/** Set the unsigned integer value */
#define rast_value_set_uint(x, val) ((x)->value.number = (val))
/** Set the string value */
#define rast_value_set_string(x, val) ((x)->value.string = (val))
/** Set the date/time value */
#define rast_value_set_date(x, val) ((x)->value.string = (val))

/** @} */

#endif

/* vim: set filetype=c sw=4 expandtab : */
